@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -41,27 +41,31 @@
 #define DOLLARNPOINTS 64
 
 #if defined(ENABLE_DOLLAR)
-#  define DOLLARSIZE 256
-#  define PHI 0.618033989
+#define DOLLARSIZE 256
+#define PHI        0.618033989
 #endif
 
-typedef struct {
-    float x,y;
+typedef struct
+{
+    float x, y;
 } SDL_FloatPoint;
 
-typedef struct {
+typedef struct
+{
     float length;
 
     int numPoints;
     SDL_FloatPoint p[MAXPATHSIZE];
 } SDL_DollarPath;
 
-typedef struct {
+typedef struct
+{
     SDL_FloatPoint path[DOLLARNPOINTS];
     unsigned long hash;
 } SDL_DollarTemplate;
 
-typedef struct {
+typedef struct
+{
     SDL_TouchID id;
     SDL_FloatPoint centroid;
     SDL_DollarPath dollarPath;
@@ -92,15 +96,18 @@ static void PrintPath(SDL_FloatPoint *path)
 int SDL_RecordGesture(SDL_TouchID touchId)
 {
     int i;
-    if (touchId < 0) recordAll = SDL_TRUE;
+    if (touchId < 0) {
+        recordAll = SDL_TRUE;
+    }
     for (i = 0; i < SDL_numGestureTouches; i++) {
         if ((touchId < 0) || (SDL_gestureTouch[i].id == touchId)) {
             SDL_gestureTouch[i].recording = SDL_TRUE;
-            if (touchId >= 0)
+            if (touchId >= 0) {
                 return 1;
+            }
         }
     }
-    return (touchId < 0);
+    return touchId < 0;
 }
 
 void SDL_GestureQuit()
@@ -109,18 +116,17 @@ void SDL_GestureQuit()
     SDL_gestureTouch = NULL;
 }
 
-static unsigned long SDL_HashDollar(SDL_FloatPoint* points)
+static unsigned long SDL_HashDollar(SDL_FloatPoint *points)
 {
     unsigned long hash = 5381;
     int i;
     for (i = 0; i < DOLLARNPOINTS; i++) {
-        hash = ((hash<<5) + hash) + (unsigned long)points[i].x;
-        hash = ((hash<<5) + hash) + (unsigned long)points[i].y;
+        hash = ((hash << 5) + hash) + (unsigned long)points[i].x;
+        hash = ((hash << 5) + hash) + (unsigned long)points[i].y;
     }
     return hash;
 }
 
-
 static int SaveTemplate(SDL_DollarTemplate *templ, SDL_RWops *dst)
 {
     if (dst == NULL) {
@@ -132,7 +138,7 @@ static int SaveTemplate(SDL_DollarTemplate *templ, SDL_RWops *dst)
 
 #if SDL_BYTEORDER == SDL_LIL_ENDIAN
     if (SDL_RWwrite(dst, templ->path,
-                    sizeof(templ->path[0]),DOLLARNPOINTS) != DOLLARNPOINTS) {
+                    sizeof(templ->path[0]), DOLLARNPOINTS) != DOLLARNPOINTS) {
         return 0;
     }
 #else
@@ -146,7 +152,7 @@ static int SaveTemplate(SDL_DollarTemplate *templ, SDL_RWops *dst)
         }
 
         if (SDL_RWwrite(dst, copy.path,
-                        sizeof(copy.path[0]),DOLLARNPOINTS) != DOLLARNPOINTS) {
+                        sizeof(copy.path[0]), DOLLARNPOINTS) != DOLLARNPOINTS) {
             return 0;
         }
     }
@@ -155,12 +161,11 @@ static int SaveTemplate(SDL_DollarTemplate *templ, SDL_RWops *dst)
     return 1;
 }
 
-
 int SDL_SaveAllDollarTemplates(SDL_RWops *dst)
 {
-    int i,j,rtrn = 0;
+    int i, j, rtrn = 0;
     for (i = 0; i < SDL_numGestureTouches; i++) {
-        SDL_GestureTouch* touch = &SDL_gestureTouch[i];
+        SDL_GestureTouch *touch = &SDL_gestureTouch[i];
         for (j = 0; j < touch->numDollarTemplates; j++) {
             rtrn += SaveTemplate(&touch->dollarTemplate[j], dst);
         }
@@ -170,9 +175,9 @@ int SDL_SaveAllDollarTemplates(SDL_RWops *dst)
 
 int SDL_SaveDollarTemplate(SDL_GestureID gestureId, SDL_RWops *dst)
 {
-    int i,j;
+    int i, j;
     for (i = 0; i < SDL_numGestureTouches; i++) {
-        SDL_GestureTouch* touch = &SDL_gestureTouch[i];
+        SDL_GestureTouch *touch = &SDL_gestureTouch[i];
         for (j = 0; j < touch->numDollarTemplates; j++) {
             if (touch->dollarTemplate[j].hash == gestureId) {
                 return SaveTemplate(&touch->dollarTemplate[j], dst);
@@ -184,9 +189,9 @@ int SDL_SaveDollarTemplate(SDL_GestureID gestureId, SDL_RWops *dst)
 
 /* path is an already sampled set of points
 Returns the index of the gesture on success, or -1 */
-static int SDL_AddDollarGesture_one(SDL_GestureTouch* inTouch, SDL_FloatPoint* path)
+static int SDL_AddDollarGesture_one(SDL_GestureTouch *inTouch, SDL_FloatPoint *path)
 {
-    SDL_DollarTemplate* dollarTemplate;
+    SDL_DollarTemplate *dollarTemplate;
     SDL_DollarTemplate *templ;
     int index;
 
@@ -194,31 +199,34 @@ static int SDL_AddDollarGesture_one(SDL_GestureTouch* inTouch, SDL_FloatPoint* p
     dollarTemplate =
         (SDL_DollarTemplate *)SDL_realloc(inTouch->dollarTemplate,
                                           (index + 1) *
-                                          sizeof(SDL_DollarTemplate));
-    if (!dollarTemplate) {
+                                              sizeof(SDL_DollarTemplate));
+    if (dollarTemplate == NULL) {
         return SDL_OutOfMemory();
     }
     inTouch->dollarTemplate = dollarTemplate;
 
     templ = &inTouch->dollarTemplate[index];
-    SDL_memcpy(templ->path, path, DOLLARNPOINTS*sizeof(SDL_FloatPoint));
+    SDL_memcpy(templ->path, path, DOLLARNPOINTS * sizeof(SDL_FloatPoint));
     templ->hash = SDL_HashDollar(templ->path);
     inTouch->numDollarTemplates++;
 
     return index;
 }
 
-static int SDL_AddDollarGesture(SDL_GestureTouch* inTouch, SDL_FloatPoint* path)
+static int SDL_AddDollarGesture(SDL_GestureTouch *inTouch, SDL_FloatPoint *path)
 {
     int index = -1;
     int i = 0;
     if (inTouch == NULL) {
-        if (SDL_numGestureTouches == 0) return SDL_SetError("no gesture touch devices registered");
+        if (SDL_numGestureTouches == 0) {
+            return SDL_SetError("no gesture touch devices registered");
+        }
         for (i = 0; i < SDL_numGestureTouches; i++) {
             inTouch = &SDL_gestureTouch[i];
             index = SDL_AddDollarGesture_one(inTouch, path);
-            if (index < 0)
+            if (index < 0) {
                 return -1;
+            }
         }
         /* Use the index of the last one added. */
         return index;
@@ -228,9 +236,11 @@ static int SDL_AddDollarGesture(SDL_GestureTouch* inTouch, SDL_FloatPoint* path)
 
 int SDL_LoadDollarTemplates(SDL_TouchID touchId, SDL_RWops *src)
 {
-    int i,loaded = 0;
+    int i, loaded = 0;
     SDL_GestureTouch *touch = NULL;
-    if (src == NULL) return 0;
+    if (src == NULL) {
+        return 0;
+    }
     if (touchId >= 0) {
         for (i = 0; i < SDL_numGestureTouches; i++) {
             if (SDL_gestureTouch[i].id == touchId) {
@@ -245,7 +255,7 @@ int SDL_LoadDollarTemplates(SDL_TouchID touchId, SDL_RWops *src)
     while (1) {
         SDL_DollarTemplate templ;
 
-        if (SDL_RWread(src,templ.path,sizeof(templ.path[0]),DOLLARNPOINTS) < DOLLARNPOINTS) {
+        if (SDL_RWread(src, templ.path, sizeof(templ.path[0]), DOLLARNPOINTS) < DOLLARNPOINTS) {
             if (loaded == 0) {
                 return SDL_SetError("could not read any dollar gesture from rwops");
             }
@@ -262,16 +272,16 @@ int SDL_LoadDollarTemplates(SDL_TouchID touchId, SDL_RWops *src)
 
         if (touchId >= 0) {
             /* printf("Adding loaded gesture to 1 touch\n"); */
-            if (SDL_AddDollarGesture(touch, templ.path) >= 0)
+            if (SDL_AddDollarGesture(touch, templ.path) >= 0) {
                 loaded++;
-        }
-        else {
+            }
+        } else {
             /* printf("Adding to: %i touches\n",SDL_numGestureTouches); */
             for (i = 0; i < SDL_numGestureTouches; i++) {
                 touch = &SDL_gestureTouch[i];
                 /* printf("Adding loaded gesture to + touches\n"); */
                 /* TODO: What if this fails? */
-                SDL_AddDollarGesture(touch,templ.path);
+                SDL_AddDollarGesture(touch, templ.path);
             }
             loaded++;
         }
@@ -280,9 +290,8 @@ int SDL_LoadDollarTemplates(SDL_TouchID touchId, SDL_RWops *src)
     return loaded;
 }
 
-
 #if defined(ENABLE_DOLLAR)
-static float dollarDifference(SDL_FloatPoint* points,SDL_FloatPoint* templ,float ang)
+static float dollarDifference(SDL_FloatPoint *points, SDL_FloatPoint *templ, float ang)
 {
     /*  SDL_FloatPoint p[DOLLARNPOINTS]; */
     float dist = 0;
@@ -291,14 +300,13 @@ static float dollarDifference(SDL_FloatPoint* points,SDL_FloatPoint* templ,float
     for (i = 0; i < DOLLARNPOINTS; i++) {
         p.x = (float)(points[i].x * SDL_cos(ang) - points[i].y * SDL_sin(ang));
         p.y = (float)(points[i].x * SDL_sin(ang) + points[i].y * SDL_cos(ang));
-        dist += (float)(SDL_sqrt((p.x-templ[i].x)*(p.x-templ[i].x)+
-                                 (p.y-templ[i].y)*(p.y-templ[i].y)));
+        dist += (float)(SDL_sqrt((p.x - templ[i].x) * (p.x - templ[i].x) +
+                                 (p.y - templ[i].y) * (p.y - templ[i].y)));
     }
-    return dist/DOLLARNPOINTS;
-
+    return dist / DOLLARNPOINTS;
 }
 
-static float bestDollarDifference(SDL_FloatPoint* points,SDL_FloatPoint* templ)
+static float bestDollarDifference(SDL_FloatPoint *points, SDL_FloatPoint *templ)
 {
     /*------------BEGIN DOLLAR BLACKBOX------------------
       -TRANSLATED DIRECTLY FROM PSUDEO-CODE AVAILABLE AT-
@@ -316,15 +324,14 @@ static float bestDollarDifference(SDL_FloatPoint* points,SDL_FloatPoint* templ)
             tb = x2;
             x2 = x1;
             f2 = f1;
-            x1 = (float)(PHI*ta + (1-PHI)*tb);
-            f1 = dollarDifference(points,templ,x1);
-        }
-        else {
+            x1 = (float)(PHI * ta + (1 - PHI) * tb);
+            f1 = dollarDifference(points, templ, x1);
+        } else {
             ta = x1;
             x1 = x2;
             f1 = f2;
-            x2 = (float)((1-PHI)*ta + PHI*tb);
-            f2 = dollarDifference(points,templ,x2);
+            x2 = (float)((1 - PHI) * ta + PHI * tb);
+            f2 = dollarDifference(points, templ, x2);
         }
     }
     /*
@@ -333,47 +340,48 @@ static float bestDollarDifference(SDL_FloatPoint* points,SDL_FloatPoint* templ)
       else if (f1 >  f2)
           printf("Min angle (x2): %f\n",x2);
     */
-    return SDL_min(f1,f2);
+    return SDL_min(f1, f2);
 }
 
 /* DollarPath contains raw points, plus (possibly) the calculated length */
-static int dollarNormalize(const SDL_DollarPath *path,SDL_FloatPoint *points, SDL_bool is_recording)
+static int dollarNormalize(const SDL_DollarPath *path, SDL_FloatPoint *points, SDL_bool is_recording)
 {
     int i;
     float interval;
     float dist;
     int numPoints = 0;
     SDL_FloatPoint centroid;
-    float xmin,xmax,ymin,ymax;
+    float xmin, xmax, ymin, ymax;
     float ang;
-    float w,h;
+    float w, h;
     float length = path->length;
 
     /* Calculate length if it hasn't already been done */
     if (length <= 0) {
-        for (i=1;i < path->numPoints; i++) {
-            float dx = path->p[i  ].x - path->p[i-1].x;
-            float dy = path->p[i  ].y - path->p[i-1].y;
-            length += (float)(SDL_sqrt(dx*dx+dy*dy));
+        for (i = 1; i < path->numPoints; i++) {
+            float dx = path->p[i].x - path->p[i - 1].x;
+            float dy = path->p[i].y - path->p[i - 1].y;
+            length += (float)(SDL_sqrt(dx * dx + dy * dy));
         }
     }
 
     /* Resample */
-    interval = length/(DOLLARNPOINTS - 1);
+    interval = length / (DOLLARNPOINTS - 1);
     dist = interval;
 
-    centroid.x = 0;centroid.y = 0;
+    centroid.x = 0;
+    centroid.y = 0;
 
     /* printf("(%f,%f)\n",path->p[path->numPoints-1].x,path->p[path->numPoints-1].y); */
     for (i = 1; i < path->numPoints; i++) {
-        float d = (float)(SDL_sqrt((path->p[i-1].x-path->p[i].x)*(path->p[i-1].x-path->p[i].x)+
-                                   (path->p[i-1].y-path->p[i].y)*(path->p[i-1].y-path->p[i].y)));
+        float d = (float)(SDL_sqrt((path->p[i - 1].x - path->p[i].x) * (path->p[i - 1].x - path->p[i].x) +
+                                   (path->p[i - 1].y - path->p[i].y) * (path->p[i - 1].y - path->p[i].y)));
         /* printf("d = %f dist = %f/%f\n",d,dist,interval); */
         while (dist + d > interval) {
-            points[numPoints].x = path->p[i-1].x +
-                ((interval-dist)/d)*(path->p[i].x-path->p[i-1].x);
-            points[numPoints].y = path->p[i-1].y +
-                ((interval-dist)/d)*(path->p[i].y-path->p[i-1].y);
+            points[numPoints].x = path->p[i - 1].x +
+                                  ((interval - dist) / d) * (path->p[i].x - path->p[i - 1].x);
+            points[numPoints].y = path->p[i - 1].y +
+                                  ((interval - dist) / d) * (path->p[i].y - path->p[i - 1].y);
             centroid.x += points[numPoints].x;
             centroid.y += points[numPoints].y;
             numPoints++;
@@ -382,14 +390,14 @@ static int dollarNormalize(const SDL_DollarPath *path,SDL_FloatPoint *points, SD
         }
         dist += d;
     }
-    if (numPoints < DOLLARNPOINTS-1) {
+    if (numPoints < DOLLARNPOINTS - 1) {
         if (is_recording) {
             SDL_SetError("ERROR: NumPoints = %i", numPoints);
         }
         return 0;
     }
     /* copy the last point */
-    points[DOLLARNPOINTS-1] = path->p[path->numPoints-1];
+    points[DOLLARNPOINTS - 1] = path->p[path->numPoints - 1];
     numPoints = DOLLARNPOINTS;
 
     centroid.x /= numPoints;
@@ -405,33 +413,40 @@ static int dollarNormalize(const SDL_DollarPath *path,SDL_FloatPoint *points, SD
     ang = (float)(SDL_atan2(centroid.y - points[0].y,
                             centroid.x - points[0].x));
 
-    for (i = 0; i<numPoints; i++) {
+    for (i = 0; i < numPoints; i++) {
         float px = points[i].x;
         float py = points[i].y;
-        points[i].x = (float)((px - centroid.x)*SDL_cos(ang) -
-                              (py - centroid.y)*SDL_sin(ang) + centroid.x);
-        points[i].y = (float)((px - centroid.x)*SDL_sin(ang) +
-                              (py - centroid.y)*SDL_cos(ang) + centroid.y);
+        points[i].x = (float)((px - centroid.x) * SDL_cos(ang) -
+                              (py - centroid.y) * SDL_sin(ang) + centroid.x);
+        points[i].y = (float)((px - centroid.x) * SDL_sin(ang) +
+                              (py - centroid.y) * SDL_cos(ang) + centroid.y);
 
-
-        if (points[i].x < xmin) xmin = points[i].x;
-        if (points[i].x > xmax) xmax = points[i].x;
-        if (points[i].y < ymin) ymin = points[i].y;
-        if (points[i].y > ymax) ymax = points[i].y;
+        if (points[i].x < xmin) {
+            xmin = points[i].x;
+        }
+        if (points[i].x > xmax) {
+            xmax = points[i].x;
+        }
+        if (points[i].y < ymin) {
+            ymin = points[i].y;
+        }
+        if (points[i].y > ymax) {
+            ymax = points[i].y;
+        }
     }
 
     /* Scale points to DOLLARSIZE, and translate to the origin */
-    w = xmax-xmin;
-    h = ymax-ymin;
+    w = xmax - xmin;
+    h = ymax - ymin;
 
-    for (i=0; i<numPoints; i++) {
-        points[i].x = (points[i].x - centroid.x)*DOLLARSIZE/w;
-        points[i].y = (points[i].y - centroid.y)*DOLLARSIZE/h;
+    for (i = 0; i < numPoints; i++) {
+        points[i].x = (points[i].x - centroid.x) * DOLLARSIZE / w;
+        points[i].y = (points[i].y - centroid.y) * DOLLARSIZE / h;
     }
     return numPoints;
 }
 
-static float dollarRecognize(const SDL_DollarPath *path,int *bestTempl,SDL_GestureTouch* touch)
+static float dollarRecognize(const SDL_DollarPath *path, int *bestTempl, SDL_GestureTouch *touch)
 {
     SDL_FloatPoint points[DOLLARNPOINTS];
     int i;
@@ -444,8 +459,11 @@ static float dollarRecognize(const SDL_DollarPath *path,int *bestTempl,SDL_Gestu
     /* PrintPath(points); */
     *bestTempl = -1;
     for (i = 0; i < touch->numDollarTemplates; i++) {
-        float diff = bestDollarDifference(points,touch->dollarTemplate[i].path);
-        if (diff < bestDiff) {bestDiff = diff; *bestTempl = i;}
+        float diff = bestDollarDifference(points, touch->dollarTemplate[i].path);
+        if (diff < bestDiff) {
+            bestDiff = diff;
+            *bestTempl = i;
+        }
     }
     return bestDiff;
 }
@@ -455,9 +473,9 @@ int SDL_GestureAddTouch(SDL_TouchID touchId)
 {
     SDL_GestureTouch *gestureTouch = (SDL_GestureTouch *)SDL_realloc(SDL_gestureTouch,
                                                                      (SDL_numGestureTouches + 1) *
-                                                                     sizeof(SDL_GestureTouch));
+                                                                         sizeof(SDL_GestureTouch));
 
-    if (!gestureTouch) {
+    if (gestureTouch == NULL) {
         return SDL_OutOfMemory();
     }
 
@@ -488,23 +506,24 @@ int SDL_GestureDelTouch(SDL_TouchID touchId)
 
     SDL_numGestureTouches--;
     if (i != SDL_numGestureTouches) {
-        SDL_memcpy(&SDL_gestureTouch[i], &SDL_gestureTouch[SDL_numGestureTouches], sizeof(SDL_gestureTouch[i]));
+        SDL_copyp(&SDL_gestureTouch[i], &SDL_gestureTouch[SDL_numGestureTouches]);
     }
     return 0;
 }
 
-static SDL_GestureTouch * SDL_GetGestureTouch(SDL_TouchID id)
+static SDL_GestureTouch *SDL_GetGestureTouch(SDL_TouchID id)
 {
     int i;
     for (i = 0; i < SDL_numGestureTouches; i++) {
         /* printf("%i ?= %i\n",SDL_gestureTouch[i].id,id); */
-        if (SDL_gestureTouch[i].id == id)
+        if (SDL_gestureTouch[i].id == id) {
             return &SDL_gestureTouch[i];
+        }
     }
     return NULL;
 }
 
-static void SDL_SendGestureMulti(SDL_GestureTouch* touch,float dTheta,float dDist)
+static void SDL_SendGestureMulti(SDL_GestureTouch *touch, float dTheta, float dDist)
 {
     if (SDL_GetEventState(SDL_MULTIGESTURE) == SDL_ENABLE) {
         SDL_Event event;
@@ -520,8 +539,8 @@ static void SDL_SendGestureMulti(SDL_GestureTouch* touch,float dTheta,float dDis
 }
 
 #if defined(ENABLE_DOLLAR)
-static void SDL_SendGestureDollar(SDL_GestureTouch* touch,
-                          SDL_GestureID gestureId,float error)
+static void SDL_SendGestureDollar(SDL_GestureTouch *touch,
+                                  SDL_GestureID gestureId, float error)
 {
     if (SDL_GetEventState(SDL_DOLLARGESTURE) == SDL_ENABLE) {
         SDL_Event event;
@@ -537,7 +556,7 @@ static void SDL_SendGestureDollar(SDL_GestureTouch* touch,
     }
 }
 
-static void SDL_SendDollarRecord(SDL_GestureTouch* touch,SDL_GestureID gestureId)
+static void SDL_SendDollarRecord(SDL_GestureTouch *touch, SDL_GestureID gestureId)
 {
     if (SDL_GetEventState(SDL_DOLLARRECORD) == SDL_ENABLE) {
         SDL_Event event;
@@ -549,10 +568,9 @@ static void SDL_SendDollarRecord(SDL_GestureTouch* touch,SDL_GestureID gestureId
 }
 #endif
 
-
-void SDL_GestureProcessEvent(SDL_Event* event)
+void SDL_GestureProcessEvent(SDL_Event *event)
 {
-    float x,y;
+    float x, y;
 #if defined(ENABLE_DOLLAR)
     int index;
     int i;
@@ -568,10 +586,12 @@ void SDL_GestureProcessEvent(SDL_Event* event)
     if (event->type == SDL_FINGERMOTION ||
         event->type == SDL_FINGERDOWN ||
         event->type == SDL_FINGERUP) {
-        SDL_GestureTouch* inTouch = SDL_GetGestureTouch(event->tfinger.touchId);
+        SDL_GestureTouch *inTouch = SDL_GetGestureTouch(event->tfinger.touchId);
 
         /* Shouldn't be possible */
-        if (inTouch == NULL) return;
+        if (inTouch == NULL) {
+            return;
+        }
 
         x = event->tfinger.x;
         y = event->tfinger.y;
@@ -590,55 +610,54 @@ void SDL_GestureProcessEvent(SDL_Event* event)
                 dollarNormalize(&inTouch->dollarPath, path, SDL_TRUE);
                 /* PrintPath(path); */
                 if (recordAll) {
-                    index = SDL_AddDollarGesture(NULL,path);
-                    for (i = 0; i < SDL_numGestureTouches; i++)
+                    index = SDL_AddDollarGesture(NULL, path);
+                    for (i = 0; i < SDL_numGestureTouches; i++) {
                         SDL_gestureTouch[i].recording = SDL_FALSE;
-                }
-                else {
-                    index = SDL_AddDollarGesture(inTouch,path);
+                    }
+                } else {
+                    index = SDL_AddDollarGesture(inTouch, path);
                 }
 
                 if (index >= 0) {
-                    SDL_SendDollarRecord(inTouch,inTouch->dollarTemplate[index].hash);
+                    SDL_SendDollarRecord(inTouch, inTouch->dollarTemplate[index].hash);
+                } else {
+                    SDL_SendDollarRecord(inTouch, -1);
                 }
-                else {
-                    SDL_SendDollarRecord(inTouch,-1);
-                }
-            }
-            else {
+            } else {
                 int bestTempl;
                 float error;
                 error = dollarRecognize(&inTouch->dollarPath,
-                                        &bestTempl,inTouch);
-                if (bestTempl >= 0){
+                                        &bestTempl, inTouch);
+                if (bestTempl >= 0) {
                     /* Send Event */
                     unsigned long gestureId = inTouch->dollarTemplate[bestTempl].hash;
-                    SDL_SendGestureDollar(inTouch,gestureId,error);
+                    SDL_SendGestureDollar(inTouch, gestureId, error);
                     /* printf ("%s\n",);("Dollar error: %f\n",error); */
                 }
             }
 #endif
             /* inTouch->gestureLast[j] = inTouch->gestureLast[inTouch->numDownFingers]; */
             if (inTouch->numDownFingers > 0) {
-                inTouch->centroid.x = (inTouch->centroid.x*(inTouch->numDownFingers+1)-
-                                       x)/inTouch->numDownFingers;
-                inTouch->centroid.y = (inTouch->centroid.y*(inTouch->numDownFingers+1)-
-                                       y)/inTouch->numDownFingers;
+                inTouch->centroid.x = (inTouch->centroid.x * (inTouch->numDownFingers + 1) -
+                                       x) /
+                                      inTouch->numDownFingers;
+                inTouch->centroid.y = (inTouch->centroid.y * (inTouch->numDownFingers + 1) -
+                                       y) /
+                                      inTouch->numDownFingers;
             }
-        }
-        else if (event->type == SDL_FINGERMOTION) {
+        } else if (event->type == SDL_FINGERMOTION) {
             float dx = event->tfinger.dx;
             float dy = event->tfinger.dy;
 #if defined(ENABLE_DOLLAR)
-            SDL_DollarPath* path = &inTouch->dollarPath;
+            SDL_DollarPath *path = &inTouch->dollarPath;
             if (path->numPoints < MAXPATHSIZE) {
                 path->p[path->numPoints].x = inTouch->centroid.x;
                 path->p[path->numPoints].y = inTouch->centroid.y;
                 pathDx =
-                    (path->p[path->numPoints].x-path->p[path->numPoints-1].x);
+                    (path->p[path->numPoints].x - path->p[path->numPoints - 1].x);
                 pathDy =
-                    (path->p[path->numPoints].y-path->p[path->numPoints-1].y);
-                path->length += (float)SDL_sqrt(pathDx*pathDx + pathDy*pathDy);
+                    (path->p[path->numPoints].y - path->p[path->numPoints - 1].y);
+                path->length += (float)SDL_sqrt(pathDx * pathDx + pathDy * pathDy);
                 path->numPoints++;
             }
 #endif
@@ -646,32 +665,36 @@ void SDL_GestureProcessEvent(SDL_Event* event)
             lastP.y = y - dy;
             lastCentroid = inTouch->centroid;
 
-            inTouch->centroid.x += dx/inTouch->numDownFingers;
-            inTouch->centroid.y += dy/inTouch->numDownFingers;
+            inTouch->centroid.x += dx / inTouch->numDownFingers;
+            inTouch->centroid.y += dy / inTouch->numDownFingers;
             /* printf("Centrid : (%f,%f)\n",inTouch->centroid.x,inTouch->centroid.y); */
             if (inTouch->numDownFingers > 1) {
                 SDL_FloatPoint lv; /* Vector from centroid to last x,y position */
-                SDL_FloatPoint v; /* Vector from centroid to current x,y position */
+                SDL_FloatPoint v;  /* Vector from centroid to current x,y position */
                 /* lv = inTouch->gestureLast[j].cv; */
                 lv.x = lastP.x - lastCentroid.x;
                 lv.y = lastP.y - lastCentroid.y;
-                lDist = (float)SDL_sqrt(lv.x*lv.x + lv.y*lv.y);
+                lDist = (float)SDL_sqrt(lv.x * lv.x + lv.y * lv.y);
                 /* printf("lDist = %f\n",lDist); */
                 v.x = x - inTouch->centroid.x;
                 v.y = y - inTouch->centroid.y;
                 /* inTouch->gestureLast[j].cv = v; */
-                Dist = (float)SDL_sqrt(v.x*v.x+v.y*v.y);
+                Dist = (float)SDL_sqrt(v.x * v.x + v.y * v.y);
                 /* SDL_cos(dTheta) = (v . lv)/(|v| * |lv|) */
 
                 /* Normalize Vectors to simplify angle calculation */
-                lv.x/=lDist;
-                lv.y/=lDist;
-                v.x/=Dist;
-                v.y/=Dist;
-                dtheta = (float)SDL_atan2(lv.x*v.y - lv.y*v.x,lv.x*v.x + lv.y*v.y);
+                lv.x /= lDist;
+                lv.y /= lDist;
+                v.x /= Dist;
+                v.y /= Dist;
+                dtheta = (float)SDL_atan2(lv.x * v.y - lv.y * v.x, lv.x * v.x + lv.y * v.y);
 
                 dDist = (Dist - lDist);
-                if (lDist == 0) {dDist = 0;dtheta = 0;} /* To avoid impossible values */
+                if (lDist == 0) {
+                    /* To avoid impossible values */
+                    dDist = 0;
+                    dtheta = 0;
+                }
 
                 /* inTouch->gestureLast[j].dDist = dDist;
                 inTouch->gestureLast[j].dtheta = dtheta;
@@ -683,9 +706,8 @@ void SDL_GestureProcessEvent(SDL_Event* event)
                 knob.ang += dtheta;
                 printf("thetaSum = %f, distSum = %f\n",gdtheta,gdDist);
                 printf("id: %i dTheta = %f, dDist = %f\n",j,dtheta,dDist); */
-                SDL_SendGestureMulti(inTouch,dtheta,dDist);
-            }
-            else {
+                SDL_SendGestureMulti(inTouch, dtheta, dDist);
+            } else {
                 /* inTouch->gestureLast[j].dDist = 0;
                 inTouch->gestureLast[j].dtheta = 0;
                 inTouch->gestureLast[j].cv.x = 0;
@@ -695,14 +717,15 @@ void SDL_GestureProcessEvent(SDL_Event* event)
             inTouch->gestureLast[j].f.p.y = y;
             break;
             pressure? */
-        }
-        else if (event->type == SDL_FINGERDOWN) {
+        } else if (event->type == SDL_FINGERDOWN) {
 
             inTouch->numDownFingers++;
-            inTouch->centroid.x = (inTouch->centroid.x*(inTouch->numDownFingers - 1)+
-                                   x)/inTouch->numDownFingers;
-            inTouch->centroid.y = (inTouch->centroid.y*(inTouch->numDownFingers - 1)+
-                                   y)/inTouch->numDownFingers;
+            inTouch->centroid.x = (inTouch->centroid.x * (inTouch->numDownFingers - 1) +
+                                   x) /
+                                  inTouch->numDownFingers;
+            inTouch->centroid.y = (inTouch->centroid.y * (inTouch->numDownFingers - 1) +
+                                   y) /
+                                  inTouch->numDownFingers;
             /* printf("Finger Down: (%f,%f). Centroid: (%f,%f\n",x,y,
                  inTouch->centroid.x,inTouch->centroid.y); */
 
