@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -45,23 +45,22 @@
 #include "SDL_render_vita_gxm_memory.h"
 #include "SDL_render_vita_gxm_shaders.h"
 
-void
-init_orthographic_matrix(float *m, float left, float right, float bottom, float top, float near, float far)
+void init_orthographic_matrix(float *m, float left, float right, float bottom, float top, float near, float far)
 {
-    m[0x0] = 2.0f/(right-left);
+    m[0x0] = 2.0f / (right - left);
     m[0x4] = 0.0f;
     m[0x8] = 0.0f;
-    m[0xC] = -(right+left)/(right-left);
+    m[0xC] = -(right + left) / (right - left);
 
     m[0x1] = 0.0f;
-    m[0x5] = 2.0f/(top-bottom);
+    m[0x5] = 2.0f / (top - bottom);
     m[0x9] = 0.0f;
-    m[0xD] = -(top+bottom)/(top-bottom);
+    m[0xD] = -(top + bottom) / (top - bottom);
 
     m[0x2] = 0.0f;
     m[0x6] = 0.0f;
-    m[0xA] = -2.0f/(far-near);
-    m[0xE] = (far+near)/(far-near);
+    m[0xA] = -2.0f / (far - near);
+    m[0xE] = (far + near) / (far - near);
 
     m[0x3] = 0.0f;
     m[0x7] = 0.0f;
@@ -69,23 +68,20 @@ init_orthographic_matrix(float *m, float left, float right, float bottom, float
     m[0xF] = 1.0f;
 }
 
-static void *
-patcher_host_alloc(void *user_data, unsigned int size)
+static void *patcher_host_alloc(void *user_data, unsigned int size)
 {
     void *mem = SDL_malloc(size);
     (void)user_data;
     return mem;
 }
 
-static void
-patcher_host_free(void *user_data, void *mem)
+static void patcher_host_free(void *user_data, void *mem)
 {
     (void)user_data;
     SDL_free(mem);
 }
 
-void *
-pool_malloc(VITA_GXM_RenderData *data, unsigned int size)
+void *pool_malloc(VITA_GXM_RenderData *data, unsigned int size)
 {
 
     if ((data->pool_index + size) < VITA_GXM_POOL_SIZE) {
@@ -97,8 +93,7 @@ pool_malloc(VITA_GXM_RenderData *data, unsigned int size)
     return NULL;
 }
 
-void *
-pool_memalign(VITA_GXM_RenderData *data, unsigned int size, unsigned int alignment)
+void *pool_memalign(VITA_GXM_RenderData *data, unsigned int size, unsigned int alignment)
 {
     unsigned int new_index = (data->pool_index + alignment - 1) & ~(alignment - 1);
     if ((new_index + size) < VITA_GXM_POOL_SIZE) {
@@ -110,8 +105,7 @@ pool_memalign(VITA_GXM_RenderData *data, unsigned int size, unsigned int alignme
     return NULL;
 }
 
-static int
-tex_format_to_bytespp(SceGxmTextureFormat format)
+static int tex_format_to_bytespp(SceGxmTextureFormat format)
 {
     switch (format & 0x9f000000U) {
     case SCE_GXM_TEXTURE_BASE_FORMAT_U8:
@@ -141,19 +135,18 @@ tex_format_to_bytespp(SceGxmTextureFormat format)
     }
 }
 
-static void
-display_callback(const void *callback_data)
+static void display_callback(const void *callback_data)
 {
     SceDisplayFrameBuf framebuf;
     const VITA_GXM_DisplayData *display_data = (const VITA_GXM_DisplayData *)callback_data;
 
     SDL_memset(&framebuf, 0x00, sizeof(SceDisplayFrameBuf));
-    framebuf.size        = sizeof(SceDisplayFrameBuf);
-    framebuf.base        = display_data->address;
-    framebuf.pitch       = VITA_GXM_SCREEN_STRIDE;
+    framebuf.size = sizeof(SceDisplayFrameBuf);
+    framebuf.base = display_data->address;
+    framebuf.pitch = VITA_GXM_SCREEN_STRIDE;
     framebuf.pixelformat = VITA_GXM_PIXEL_FORMAT;
-    framebuf.width       = VITA_GXM_SCREEN_WIDTH;
-    framebuf.height      = VITA_GXM_SCREEN_HEIGHT;
+    framebuf.width = VITA_GXM_SCREEN_WIDTH;
+    framebuf.height = VITA_GXM_SCREEN_HEIGHT;
     sceDisplaySetFrameBuf(&framebuf, SCE_DISPLAY_SETBUF_NEXTFRAME);
 
     if (display_data->wait_vblank) {
@@ -161,16 +154,14 @@ display_callback(const void *callback_data)
     }
 }
 
-static void
-free_fragment_programs(VITA_GXM_RenderData *data, fragment_programs *out)
+static void free_fragment_programs(VITA_GXM_RenderData *data, fragment_programs *out)
 {
     sceGxmShaderPatcherReleaseFragmentProgram(data->shaderPatcher, out->color);
     sceGxmShaderPatcherReleaseFragmentProgram(data->shaderPatcher, out->texture);
 }
 
-static void
-make_fragment_programs(VITA_GXM_RenderData *data, fragment_programs *out,
-    const SceGxmBlendInfo *blend_info)
+static void make_fragment_programs(VITA_GXM_RenderData *data, fragment_programs *out,
+                                   const SceGxmBlendInfo *blend_info)
 {
     int err;
 
@@ -181,8 +172,7 @@ make_fragment_programs(VITA_GXM_RenderData *data, fragment_programs *out,
         0,
         blend_info,
         colorVertexProgramGxp,
-        &out->color
-    );
+        &out->color);
 
     if (err != 0) {
         SDL_LogError(SDL_LOG_CATEGORY_RENDER, "Patcher create fragment failed: %d\n", err);
@@ -196,8 +186,7 @@ make_fragment_programs(VITA_GXM_RenderData *data, fragment_programs *out,
         0,
         blend_info,
         textureVertexProgramGxp,
-        &out->texture
-    );
+        &out->texture);
 
     if (err != 0) {
         SDL_LogError(SDL_LOG_CATEGORY_RENDER, "Patcher create fragment failed: %d\n", err);
@@ -205,16 +194,13 @@ make_fragment_programs(VITA_GXM_RenderData *data, fragment_programs *out,
     }
 }
 
-
-static void
-set_stencil_mask(VITA_GXM_RenderData *data, float x, float y, float w, float h)
+static void set_stencil_mask(VITA_GXM_RenderData *data, float x, float y, float w, float h)
 {
     void *vertexDefaultBuffer;
     color_vertex *vertices = (color_vertex *)pool_memalign(
         data,
         4 * sizeof(color_vertex), // 4 vertices
-        sizeof(color_vertex)
-    );
+        sizeof(color_vertex));
 
     vertices[0].x = x;
     vertices[0].y = y;
@@ -256,11 +242,9 @@ set_stencil_mask(VITA_GXM_RenderData *data, float x, float y, float w, float h)
     sceGxmDraw(data->gxm_context, SCE_GXM_PRIMITIVE_TRIANGLE_STRIP, SCE_GXM_INDEX_FORMAT_U16, data->linearIndices, 4);
 }
 
-
-void
-set_clip_rectangle(VITA_GXM_RenderData *data, int x_min, int y_min, int x_max, int y_max)
+void set_clip_rectangle(VITA_GXM_RenderData *data, int x_min, int y_min, int x_max, int y_max)
 {
-    if(data->drawing) {
+    if (data->drawing) {
         // clear the stencil buffer to 0
         sceGxmSetFrontStencilFunc(
             data->gxm_context,
@@ -269,8 +253,7 @@ set_clip_rectangle(VITA_GXM_RenderData *data, int x_min, int y_min, int x_max, i
             SCE_GXM_STENCIL_OP_ZERO,
             SCE_GXM_STENCIL_OP_ZERO,
             0xFF,
-            0xFF
-        );
+            0xFF);
 
         set_stencil_mask(data, 0, 0, VITA_GXM_SCREEN_WIDTH, VITA_GXM_SCREEN_HEIGHT);
 
@@ -282,8 +265,7 @@ set_clip_rectangle(VITA_GXM_RenderData *data, int x_min, int y_min, int x_max, i
             SCE_GXM_STENCIL_OP_REPLACE,
             SCE_GXM_STENCIL_OP_REPLACE,
             0xFF,
-            0xFF
-        );
+            0xFF);
 
         set_stencil_mask(data, x_min, y_min, x_max - x_min, y_max - y_min);
 
@@ -295,13 +277,11 @@ set_clip_rectangle(VITA_GXM_RenderData *data, int x_min, int y_min, int x_max, i
             SCE_GXM_STENCIL_OP_KEEP,
             SCE_GXM_STENCIL_OP_KEEP,
             0xFF,
-            0xFF
-        );
+            0xFF);
     }
 }
 
-void
-unset_clip_rectangle(VITA_GXM_RenderData *data)
+void unset_clip_rectangle(VITA_GXM_RenderData *data)
 {
     sceGxmSetFrontStencilFunc(
         data->gxm_context,
@@ -310,12 +290,10 @@ unset_clip_rectangle(VITA_GXM_RenderData *data)
         SCE_GXM_STENCIL_OP_KEEP,
         SCE_GXM_STENCIL_OP_KEEP,
         0xFF,
-        0xFF
-    );
+        0xFF);
 }
 
-int
-gxm_init(SDL_Renderer *renderer)
+int gxm_init(SDL_Renderer *renderer)
 {
     unsigned int i, x, y;
     int err;
@@ -341,38 +319,38 @@ gxm_init(SDL_Renderer *renderer)
     unsigned int depthStrideInSamples = alignedWidth;
 
     // set buffer sizes for this sample
-    const unsigned int patcherBufferSize        = 64*1024;
-    const unsigned int patcherVertexUsseSize    = 64*1024;
-    const unsigned int patcherFragmentUsseSize  = 64*1024;
+    const unsigned int patcherBufferSize = 64 * 1024;
+    const unsigned int patcherVertexUsseSize = 64 * 1024;
+    const unsigned int patcherFragmentUsseSize = 64 * 1024;
 
     // Fill SceGxmBlendInfo
     static const SceGxmBlendInfo blend_info_none = {
         .colorFunc = SCE_GXM_BLEND_FUNC_NONE,
         .alphaFunc = SCE_GXM_BLEND_FUNC_NONE,
-        .colorSrc  = SCE_GXM_BLEND_FACTOR_ZERO,
-        .colorDst  = SCE_GXM_BLEND_FACTOR_ZERO,
-        .alphaSrc  = SCE_GXM_BLEND_FACTOR_ZERO,
-        .alphaDst  = SCE_GXM_BLEND_FACTOR_ZERO,
+        .colorSrc = SCE_GXM_BLEND_FACTOR_ZERO,
+        .colorDst = SCE_GXM_BLEND_FACTOR_ZERO,
+        .alphaSrc = SCE_GXM_BLEND_FACTOR_ZERO,
+        .alphaDst = SCE_GXM_BLEND_FACTOR_ZERO,
         .colorMask = SCE_GXM_COLOR_MASK_ALL
     };
 
     static const SceGxmBlendInfo blend_info_blend = {
         .colorFunc = SCE_GXM_BLEND_FUNC_ADD,
         .alphaFunc = SCE_GXM_BLEND_FUNC_ADD,
-        .colorSrc  = SCE_GXM_BLEND_FACTOR_SRC_ALPHA,
-        .colorDst  = SCE_GXM_BLEND_FACTOR_ONE_MINUS_SRC_ALPHA,
-        .alphaSrc  = SCE_GXM_BLEND_FACTOR_ONE,
-        .alphaDst  = SCE_GXM_BLEND_FACTOR_ONE_MINUS_SRC_ALPHA,
+        .colorSrc = SCE_GXM_BLEND_FACTOR_SRC_ALPHA,
+        .colorDst = SCE_GXM_BLEND_FACTOR_ONE_MINUS_SRC_ALPHA,
+        .alphaSrc = SCE_GXM_BLEND_FACTOR_ONE,
+        .alphaDst = SCE_GXM_BLEND_FACTOR_ONE_MINUS_SRC_ALPHA,
         .colorMask = SCE_GXM_COLOR_MASK_ALL
     };
 
     static const SceGxmBlendInfo blend_info_add = {
         .colorFunc = SCE_GXM_BLEND_FUNC_ADD,
         .alphaFunc = SCE_GXM_BLEND_FUNC_ADD,
-        .colorSrc  = SCE_GXM_BLEND_FACTOR_SRC_ALPHA,
-        .colorDst  = SCE_GXM_BLEND_FACTOR_ONE,
-        .alphaSrc  = SCE_GXM_BLEND_FACTOR_ZERO,
-        .alphaDst  = SCE_GXM_BLEND_FACTOR_ONE,
+        .colorSrc = SCE_GXM_BLEND_FACTOR_SRC_ALPHA,
+        .colorDst = SCE_GXM_BLEND_FACTOR_ONE,
+        .alphaSrc = SCE_GXM_BLEND_FACTOR_ZERO,
+        .alphaDst = SCE_GXM_BLEND_FACTOR_ONE,
         .colorMask = SCE_GXM_COLOR_MASK_ALL
     };
 
@@ -380,33 +358,33 @@ gxm_init(SDL_Renderer *renderer)
         .colorFunc = SCE_GXM_BLEND_FUNC_ADD,
         .alphaFunc = SCE_GXM_BLEND_FUNC_ADD,
 
-        .colorSrc  = SCE_GXM_BLEND_FACTOR_ZERO,
-        .colorDst  = SCE_GXM_BLEND_FACTOR_SRC_COLOR,
+        .colorSrc = SCE_GXM_BLEND_FACTOR_ZERO,
+        .colorDst = SCE_GXM_BLEND_FACTOR_SRC_COLOR,
 
-        .alphaSrc  = SCE_GXM_BLEND_FACTOR_ZERO,
-        .alphaDst  = SCE_GXM_BLEND_FACTOR_ONE,
+        .alphaSrc = SCE_GXM_BLEND_FACTOR_ZERO,
+        .alphaDst = SCE_GXM_BLEND_FACTOR_ONE,
         .colorMask = SCE_GXM_COLOR_MASK_ALL
     };
 
     static const SceGxmBlendInfo blend_info_mul = {
         .colorFunc = SCE_GXM_BLEND_FUNC_ADD,
         .alphaFunc = SCE_GXM_BLEND_FUNC_ADD,
-        .colorSrc  = SCE_GXM_BLEND_FACTOR_DST_COLOR,
-        .colorDst  = SCE_GXM_BLEND_FACTOR_ONE_MINUS_SRC_ALPHA,
-        .alphaSrc  = SCE_GXM_BLEND_FACTOR_DST_ALPHA,
-        .alphaDst  = SCE_GXM_BLEND_FACTOR_ONE_MINUS_SRC_ALPHA,
+        .colorSrc = SCE_GXM_BLEND_FACTOR_DST_COLOR,
+        .colorDst = SCE_GXM_BLEND_FACTOR_ONE_MINUS_SRC_ALPHA,
+        .alphaSrc = SCE_GXM_BLEND_FACTOR_DST_ALPHA,
+        .alphaDst = SCE_GXM_BLEND_FACTOR_ONE_MINUS_SRC_ALPHA,
         .colorMask = SCE_GXM_COLOR_MASK_ALL
     };
 
-    VITA_GXM_RenderData *data = (VITA_GXM_RenderData *) renderer->driverdata;
+    VITA_GXM_RenderData *data = (VITA_GXM_RenderData *)renderer->driverdata;
 
     SceGxmInitializeParams initializeParams;
     SDL_memset(&initializeParams, 0, sizeof(SceGxmInitializeParams));
-    initializeParams.flags                          = 0;
-    initializeParams.displayQueueMaxPendingCount    = VITA_GXM_PENDING_SWAPS;
-    initializeParams.displayQueueCallback           = display_callback;
-    initializeParams.displayQueueCallbackDataSize   = sizeof(VITA_GXM_DisplayData);
-    initializeParams.parameterBufferSize            = SCE_GXM_DEFAULT_PARAMETER_BUFFER_SIZE;
+    initializeParams.flags = 0;
+    initializeParams.displayQueueMaxPendingCount = VITA_GXM_PENDING_SWAPS;
+    initializeParams.displayQueueCallback = display_callback;
+    initializeParams.displayQueueCallbackDataSize = sizeof(VITA_GXM_DisplayData);
+    initializeParams.parameterBufferSize = SCE_GXM_DEFAULT_PARAMETER_BUFFER_SIZE;
 
     err = sceGxmInitialize(&initializeParams);
 
@@ -443,17 +421,17 @@ gxm_init(SDL_Renderer *renderer)
         &fragmentUsseRingBufferOffset);
 
     SDL_memset(&data->contextParams, 0, sizeof(SceGxmContextParams));
-    data->contextParams.hostMem                       = SDL_malloc(SCE_GXM_MINIMUM_CONTEXT_HOST_MEM_SIZE);
-    data->contextParams.hostMemSize                   = SCE_GXM_MINIMUM_CONTEXT_HOST_MEM_SIZE;
-    data->contextParams.vdmRingBufferMem              = vdmRingBuffer;
-    data->contextParams.vdmRingBufferMemSize          = SCE_GXM_DEFAULT_VDM_RING_BUFFER_SIZE;
-    data->contextParams.vertexRingBufferMem           = vertexRingBuffer;
-    data->contextParams.vertexRingBufferMemSize       = SCE_GXM_DEFAULT_VERTEX_RING_BUFFER_SIZE;
-    data->contextParams.fragmentRingBufferMem         = fragmentRingBuffer;
-    data->contextParams.fragmentRingBufferMemSize     = SCE_GXM_DEFAULT_FRAGMENT_RING_BUFFER_SIZE;
-    data->contextParams.fragmentUsseRingBufferMem     = fragmentUsseRingBuffer;
+    data->contextParams.hostMem = SDL_malloc(SCE_GXM_MINIMUM_CONTEXT_HOST_MEM_SIZE);
+    data->contextParams.hostMemSize = SCE_GXM_MINIMUM_CONTEXT_HOST_MEM_SIZE;
+    data->contextParams.vdmRingBufferMem = vdmRingBuffer;
+    data->contextParams.vdmRingBufferMemSize = SCE_GXM_DEFAULT_VDM_RING_BUFFER_SIZE;
+    data->contextParams.vertexRingBufferMem = vertexRingBuffer;
+    data->contextParams.vertexRingBufferMemSize = SCE_GXM_DEFAULT_VERTEX_RING_BUFFER_SIZE;
+    data->contextParams.fragmentRingBufferMem = fragmentRingBuffer;
+    data->contextParams.fragmentRingBufferMemSize = SCE_GXM_DEFAULT_FRAGMENT_RING_BUFFER_SIZE;
+    data->contextParams.fragmentUsseRingBufferMem = fragmentUsseRingBuffer;
     data->contextParams.fragmentUsseRingBufferMemSize = SCE_GXM_DEFAULT_FRAGMENT_USSE_RING_BUFFER_SIZE;
-    data->contextParams.fragmentUsseRingBufferOffset  = fragmentUsseRingBufferOffset;
+    data->contextParams.fragmentUsseRingBufferOffset = fragmentUsseRingBufferOffset;
 
     err = sceGxmCreateContext(&data->contextParams, &data->gxm_context);
     if (err != 0) {
@@ -463,13 +441,13 @@ gxm_init(SDL_Renderer *renderer)
 
     // set up parameters
     SDL_memset(&renderTargetParams, 0, sizeof(SceGxmRenderTargetParams));
-    renderTargetParams.flags                = 0;
-    renderTargetParams.width                = VITA_GXM_SCREEN_WIDTH;
-    renderTargetParams.height               = VITA_GXM_SCREEN_HEIGHT;
-    renderTargetParams.scenesPerFrame       = 1;
-    renderTargetParams.multisampleMode      = 0;
+    renderTargetParams.flags = 0;
+    renderTargetParams.width = VITA_GXM_SCREEN_WIDTH;
+    renderTargetParams.height = VITA_GXM_SCREEN_HEIGHT;
+    renderTargetParams.scenesPerFrame = 1;
+    renderTargetParams.multisampleMode = 0;
     renderTargetParams.multisampleLocations = 0;
-    renderTargetParams.driverMemBlock       = -1; // Invalid UID
+    renderTargetParams.driverMemBlock = -1; // Invalid UID
 
     // create the render target
     err = sceGxmCreateRenderTarget(&renderTargetParams, &data->renderTarget);
@@ -507,25 +485,21 @@ gxm_init(SDL_Renderer *renderer)
             VITA_GXM_SCREEN_WIDTH,
             VITA_GXM_SCREEN_HEIGHT,
             VITA_GXM_SCREEN_STRIDE,
-            data->displayBufferData[i]
-        );
+            data->displayBufferData[i]);
 
         if (err != 0) {
             SDL_LogError(SDL_LOG_CATEGORY_RENDER, "color surface init failed: %d\n", err);
             return err;
         }
 
-
         // create a sync object that we will associate with this buffer
         err = sceGxmSyncObjectCreate(&data->displayBufferSync[i]);
         if (err != 0) {
             SDL_LogError(SDL_LOG_CATEGORY_RENDER, "sync object creation failed: %d\n", err);
             return err;
         }
-
     }
 
-
     // allocate the depth buffer
     data->depthBufferData = vita_mem_alloc(
         SCE_KERNEL_MEMBLOCK_TYPE_USER_RW_UNCACHE,
@@ -554,7 +528,6 @@ gxm_init(SDL_Renderer *renderer)
     // set the stencil test reference (this is currently assumed to always remain 1 after here for region clipping)
     sceGxmSetFrontStencilRef(data->gxm_context, 1);
 
-
     // set the stencil function (this wouldn't actually be needed, as the set clip rectangle function has to call this at the begginning of every scene)
     sceGxmSetFrontStencilFunc(
         data->gxm_context,
@@ -565,7 +538,6 @@ gxm_init(SDL_Renderer *renderer)
         0xFF,
         0xFF);
 
-
     // allocate memory for buffers and USSE code
     patcherBuffer = vita_mem_alloc(
         SCE_KERNEL_MEMBLOCK_TYPE_USER_RW_UNCACHE,
@@ -586,23 +558,23 @@ gxm_init(SDL_Renderer *renderer)
 
     // create a shader patcher
     SDL_memset(&patcherParams, 0, sizeof(SceGxmShaderPatcherParams));
-    patcherParams.userData                  = NULL;
-    patcherParams.hostAllocCallback         = &patcher_host_alloc;
-    patcherParams.hostFreeCallback          = &patcher_host_free;
-    patcherParams.bufferAllocCallback       = NULL;
-    patcherParams.bufferFreeCallback        = NULL;
-    patcherParams.bufferMem                 = patcherBuffer;
-    patcherParams.bufferMemSize             = patcherBufferSize;
-    patcherParams.vertexUsseAllocCallback   = NULL;
-    patcherParams.vertexUsseFreeCallback    = NULL;
-    patcherParams.vertexUsseMem             = patcherVertexUsse;
-    patcherParams.vertexUsseMemSize         = patcherVertexUsseSize;
-    patcherParams.vertexUsseOffset          = patcherVertexUsseOffset;
+    patcherParams.userData = NULL;
+    patcherParams.hostAllocCallback = &patcher_host_alloc;
+    patcherParams.hostFreeCallback = &patcher_host_free;
+    patcherParams.bufferAllocCallback = NULL;
+    patcherParams.bufferFreeCallback = NULL;
+    patcherParams.bufferMem = patcherBuffer;
+    patcherParams.bufferMemSize = patcherBufferSize;
+    patcherParams.vertexUsseAllocCallback = NULL;
+    patcherParams.vertexUsseFreeCallback = NULL;
+    patcherParams.vertexUsseMem = patcherVertexUsse;
+    patcherParams.vertexUsseMemSize = patcherVertexUsseSize;
+    patcherParams.vertexUsseOffset = patcherVertexUsseOffset;
     patcherParams.fragmentUsseAllocCallback = NULL;
-    patcherParams.fragmentUsseFreeCallback  = NULL;
-    patcherParams.fragmentUsseMem           = patcherFragmentUsse;
-    patcherParams.fragmentUsseMemSize       = patcherFragmentUsseSize;
-    patcherParams.fragmentUsseOffset        = patcherFragmentUsseOffset;
+    patcherParams.fragmentUsseFreeCallback = NULL;
+    patcherParams.fragmentUsseMem = patcherFragmentUsse;
+    patcherParams.fragmentUsseMemSize = patcherFragmentUsseSize;
+    patcherParams.fragmentUsseOffset = patcherFragmentUsseOffset;
 
     err = sceGxmShaderPatcherCreate(&patcherParams, &data->shaderPatcher);
     if (err != 0) {
@@ -610,7 +582,6 @@ gxm_init(SDL_Renderer *renderer)
         return err;
     }
 
-
     // check the shaders
     err = sceGxmProgramCheck(clearVertexProgramGxp);
     if (err != 0) {
@@ -692,13 +663,13 @@ gxm_init(SDL_Renderer *renderer)
         // create clear vertex format
         SceGxmVertexAttribute clearVertexAttributes[1];
         SceGxmVertexStream clearVertexStreams[1];
-        clearVertexAttributes[0].streamIndex    = 0;
-        clearVertexAttributes[0].offset         = 0;
-        clearVertexAttributes[0].format         = SCE_GXM_ATTRIBUTE_FORMAT_F32;
+        clearVertexAttributes[0].streamIndex = 0;
+        clearVertexAttributes[0].offset = 0;
+        clearVertexAttributes[0].format = SCE_GXM_ATTRIBUTE_FORMAT_F32;
         clearVertexAttributes[0].componentCount = 2;
-        clearVertexAttributes[0].regIndex       = sceGxmProgramParameterGetResourceIndex(paramClearPositionAttribute);
-        clearVertexStreams[0].stride            = sizeof(clear_vertex);
-        clearVertexStreams[0].indexSource       = SCE_GXM_INDEX_SOURCE_INDEX_16BIT;
+        clearVertexAttributes[0].regIndex = sceGxmProgramParameterGetResourceIndex(paramClearPositionAttribute);
+        clearVertexStreams[0].stride = sizeof(clear_vertex);
+        clearVertexStreams[0].indexSource = SCE_GXM_INDEX_SOURCE_INDEX_16BIT;
 
         // create clear programs
         err = sceGxmShaderPatcherCreateVertexProgram(
@@ -708,8 +679,7 @@ gxm_init(SDL_Renderer *renderer)
             1,
             clearVertexStreams,
             1,
-            &data->clearVertexProgram
-        );
+            &data->clearVertexProgram);
         if (err != 0) {
             SDL_LogError(SDL_LOG_CATEGORY_RENDER, "create program (clear vertex) failed: %d\n", err);
             return err;
@@ -722,8 +692,7 @@ gxm_init(SDL_Renderer *renderer)
             0,
             NULL,
             clearVertexProgramGxp,
-            &data->clearFragmentProgram
-        );
+            &data->clearFragmentProgram);
         if (err != 0) {
             SDL_LogError(SDL_LOG_CATEGORY_RENDER, "create program (clear fragment) failed: %d\n", err);
             return err;
@@ -732,11 +701,10 @@ gxm_init(SDL_Renderer *renderer)
         // create the clear triangle vertex/index data
         data->clearVertices = (clear_vertex *)vita_mem_alloc(
             SCE_KERNEL_MEMBLOCK_TYPE_USER_RW_UNCACHE,
-            3*sizeof(clear_vertex),
+            3 * sizeof(clear_vertex),
             4,
             SCE_GXM_MEMORY_ATTRIB_READ,
-            &data->clearVerticesUid
-        );
+            &data->clearVerticesUid);
     }
 
     // Allocate a 64k * 2 bytes = 128 KiB buffer and store all possible
@@ -744,23 +712,21 @@ gxm_init(SDL_Renderer *renderer)
     // all drawing operations where we don't want to use indexing.
     data->linearIndices = (uint16_t *)vita_mem_alloc(
         SCE_KERNEL_MEMBLOCK_TYPE_USER_RW_UNCACHE,
-        UINT16_MAX*sizeof(uint16_t),
+        UINT16_MAX * sizeof(uint16_t),
         sizeof(uint16_t),
         SCE_GXM_MEMORY_ATTRIB_READ,
-        &data->linearIndicesUid
-    );
+        &data->linearIndicesUid);
 
-    for (i = 0; i <= UINT16_MAX; ++i)
-    {
+    for (i = 0; i <= UINT16_MAX; ++i) {
         data->linearIndices[i] = i;
     }
 
     data->clearVertices[0].x = -1.0f;
     data->clearVertices[0].y = -1.0f;
-    data->clearVertices[1].x =  3.0f;
+    data->clearVertices[1].x = 3.0f;
     data->clearVertices[1].y = -1.0f;
     data->clearVertices[2].x = -1.0f;
-    data->clearVertices[2].y =  3.0f;
+    data->clearVertices[2].y = 3.0f;
 
     {
         const SceGxmProgramParameter *paramColorPositionAttribute = sceGxmProgramFindParameterByName(colorVertexProgramGxp, "aPosition");
@@ -794,16 +760,13 @@ gxm_init(SDL_Renderer *renderer)
             2,
             colorVertexStreams,
             1,
-            &data->colorVertexProgram
-        );
+            &data->colorVertexProgram);
         if (err != 0) {
             SDL_LogError(SDL_LOG_CATEGORY_RENDER, "create program (color vertex) failed: %d\n", err);
             return err;
         }
-
     }
 
-
     {
         const SceGxmProgramParameter *paramTexturePositionAttribute = sceGxmProgramFindParameterByName(textureVertexProgramGxp, "aPosition");
         const SceGxmProgramParameter *paramTextureTexcoordAttribute = sceGxmProgramFindParameterByName(textureVertexProgramGxp, "aTexcoord");
@@ -842,13 +805,11 @@ gxm_init(SDL_Renderer *renderer)
             3,
             textureVertexStreams,
             1,
-            &data->textureVertexProgram
-        );
+            &data->textureVertexProgram);
         if (err != 0) {
             SDL_LogError(SDL_LOG_CATEGORY_RENDER, "create program (texture vertex) failed: %x\n", err);
             return err;
         }
-
     }
 
     // Create variations of the fragment program based on blending mode
@@ -864,7 +825,6 @@ gxm_init(SDL_Renderer *renderer)
 
         data->colorFragmentProgram = in->color;
         data->textureFragmentProgram = in->texture;
-
     }
 
     // find vertex uniforms by name and cache parameter information
@@ -878,16 +838,14 @@ gxm_init(SDL_Renderer *renderer)
         VITA_GXM_POOL_SIZE,
         sizeof(void *),
         SCE_GXM_MEMORY_ATTRIB_READ,
-        &data->poolUid[0]
-    );
+        &data->poolUid[0]);
 
     data->pool_addr[1] = vita_mem_alloc(
         SCE_KERNEL_MEMBLOCK_TYPE_USER_RW,
         VITA_GXM_POOL_SIZE,
         sizeof(void *),
         SCE_GXM_MEMORY_ATTRIB_READ,
-        &data->poolUid[1]
-    );
+        &data->poolUid[1]);
 
     init_orthographic_matrix(data->ortho_matrix, 0.0f, VITA_GXM_SCREEN_WIDTH, VITA_GXM_SCREEN_HEIGHT, 0.0f, 0.0f, 1.0f);
 
@@ -902,7 +860,7 @@ gxm_init(SDL_Renderer *renderer)
 
 void gxm_finish(SDL_Renderer *renderer)
 {
-    VITA_GXM_RenderData *data = (VITA_GXM_RenderData *) renderer->driverdata;
+    VITA_GXM_RenderData *data = (VITA_GXM_RenderData *)renderer->driverdata;
 
     // wait until rendering is done
     sceGxmFinish(data->gxm_context);
@@ -913,7 +871,6 @@ void gxm_finish(SDL_Renderer *renderer)
     sceGxmShaderPatcherReleaseVertexProgram(data->shaderPatcher, data->colorVertexProgram);
     sceGxmShaderPatcherReleaseVertexProgram(data->shaderPatcher, data->textureVertexProgram);
 
-
     free_fragment_programs(data, &data->blendFragmentPrograms.blend_mode_none);
     free_fragment_programs(data, &data->blendFragmentPrograms.blend_mode_blend);
     free_fragment_programs(data, &data->blendFragmentPrograms.blend_mode_add);
@@ -929,8 +886,7 @@ void gxm_finish(SDL_Renderer *renderer)
     // clean up display queue
     vita_mem_free(data->depthBufferUid);
 
-    for (size_t i = 0; i < VITA_GXM_BUFFERS; i++)
-    {
+    for (size_t i = 0; i < VITA_GXM_BUFFERS; i++) {
         // clear the buffer then deallocate
         SDL_memset(data->displayBufferData[i], 0, VITA_GXM_SCREEN_HEIGHT * VITA_GXM_SCREEN_STRIDE * 4);
         vita_mem_free(data->displayBufferUid[i]);
@@ -977,8 +933,7 @@ void gxm_finish(SDL_Renderer *renderer)
 
 // textures
 
-void
-free_gxm_texture(VITA_GXM_RenderData *data, gxm_texture *texture)
+void free_gxm_texture(VITA_GXM_RenderData *data, gxm_texture *texture)
 {
     if (texture) {
         if (texture->gxm_rendertarget) {
@@ -1002,36 +957,55 @@ gxm_texture_get_format(const gxm_texture *texture)
     return sceGxmTextureGetFormat(&texture->gxm_tex);
 }
 
-void *
-gxm_texture_get_datap(const gxm_texture *texture)
+void *gxm_texture_get_datap(const gxm_texture *texture)
 {
     return sceGxmTextureGetData(&texture->gxm_tex);
 }
 
-gxm_texture *
-create_gxm_texture(VITA_GXM_RenderData *data, unsigned int w, unsigned int h, SceGxmTextureFormat format, unsigned int isRenderTarget, unsigned int *return_w, unsigned int *return_h, unsigned int *return_pitch, float *return_wscale)
+static SceGxmColorFormat tex_format_to_color_format(SceGxmTextureFormat format)
+{
+    switch (format) {
+    case SCE_GXM_TEXTURE_FORMAT_U8U8U8U8_ARGB:
+        return SCE_GXM_COLOR_FORMAT_U8U8U8U8_ARGB;
+    case SCE_GXM_TEXTURE_FORMAT_U8U8U8_RGB:
+        return SCE_GXM_COLOR_FORMAT_U8U8U8_RGB;
+    case SCE_GXM_TEXTURE_FORMAT_U8U8U8_BGR:
+        return SCE_GXM_COLOR_FORMAT_U8U8U8_BGR;
+    case SCE_GXM_TEXTURE_FORMAT_U8U8U8U8_ABGR:
+        return SCE_GXM_COLOR_FORMAT_U8U8U8U8_ABGR;
+    case SCE_GXM_TEXTURE_FORMAT_U5U6U5_RGB:
+        return SCE_GXM_COLOR_FORMAT_U5U6U5_RGB;
+    case SCE_GXM_TEXTURE_FORMAT_U5U6U5_BGR:
+        return SCE_GXM_COLOR_FORMAT_U5U6U5_BGR;
+    default:
+        return SCE_GXM_COLOR_FORMAT_U8U8U8U8_ABGR;
+    }
+}
+
+gxm_texture *create_gxm_texture(VITA_GXM_RenderData *data, unsigned int w, unsigned int h, SceGxmTextureFormat format, unsigned int isRenderTarget, unsigned int *return_w, unsigned int *return_h, unsigned int *return_pitch, float *return_wscale)
 {
     gxm_texture *texture = SDL_calloc(1, sizeof(gxm_texture));
     int aligned_w = ALIGN(w, 8);
     int texture_w = w;
-    int tex_size =  aligned_w * h * tex_format_to_bytespp(format);
+    int tex_size = aligned_w * h * tex_format_to_bytespp(format);
     void *texture_data;
     int ret;
 
     *return_wscale = 1.0f;
 
     // SCE_GXM_TEXTURE_BASE_FORMAT_YUV420P3/P2 based formats require width aligned to 16
-    if ( (format & 0x9f000000U) == SCE_GXM_TEXTURE_BASE_FORMAT_YUV420P3 || (format & 0x9f000000U) == SCE_GXM_TEXTURE_BASE_FORMAT_YUV420P2) {
+    if ((format & 0x9f000000U) == SCE_GXM_TEXTURE_BASE_FORMAT_YUV420P3 || (format & 0x9f000000U) == SCE_GXM_TEXTURE_BASE_FORMAT_YUV420P2) {
         aligned_w = ALIGN(w, 16);
         texture_w = aligned_w;
-        tex_size =  aligned_w * h * tex_format_to_bytespp(format);
-        *return_wscale = (float) (w) / texture_w;
+        tex_size = aligned_w * h * tex_format_to_bytespp(format);
+        *return_wscale = (float)(w) / texture_w;
         // add storage for UV planes
         tex_size += (((aligned_w + 1) / 2) * ((h + 1) / 2)) * 2;
     }
 
-    if (!texture)
+    if (texture == NULL) {
         return NULL;
+    }
 
     *return_w = w;
     *return_h = h;
@@ -1040,25 +1014,23 @@ create_gxm_texture(VITA_GXM_RenderData *data, unsigned int w, unsigned int h, Sc
     /* Allocate a GPU buffer for the texture */
     texture_data = vita_gpu_mem_alloc(
         data,
-        tex_size
-    );
+        tex_size);
 
     /* Try SCE_KERNEL_MEMBLOCK_TYPE_USER_RW_UNCACHE in case we're out of VRAM */
-    if (!texture_data) {
+    if (texture_data == NULL) {
         SDL_LogWarn(SDL_LOG_CATEGORY_RENDER, "CDRAM texture allocation failed\n");
         texture_data = vita_mem_alloc(
             SCE_KERNEL_MEMBLOCK_TYPE_USER_RW_UNCACHE,
             tex_size,
             SCE_GXM_TEXTURE_ALIGNMENT,
             SCE_GXM_MEMORY_ATTRIB_READ | SCE_GXM_MEMORY_ATTRIB_WRITE,
-            &texture->data_UID
-        );
+            &texture->data_UID);
         texture->cdram = 0;
     } else {
         texture->cdram = 1;
     }
 
-    if (!texture_data) {
+    if (texture_data == NULL) {
         SDL_free(texture);
         return NULL;
     }
@@ -1067,32 +1039,31 @@ create_gxm_texture(VITA_GXM_RenderData *data, unsigned int w, unsigned int h, Sc
     SDL_memset(texture_data, 0, tex_size);
 
     /* Create the gxm texture */
-    ret = sceGxmTextureInitLinear( &texture->gxm_tex, texture_data, format, texture_w, h, 0);
+    ret = sceGxmTextureInitLinear(&texture->gxm_tex, texture_data, format, texture_w, h, 0);
     if (ret < 0) {
-      free_gxm_texture(data, texture);
-      SDL_LogError(SDL_LOG_CATEGORY_RENDER, "texture init failed: %x\n", ret);
-      return NULL;
+        free_gxm_texture(data, texture);
+        SDL_LogError(SDL_LOG_CATEGORY_RENDER, "texture init failed: %x\n", ret);
+        return NULL;
     }
 
     if (isRenderTarget) {
         void *depthBufferData;
         const uint32_t alignedWidth = ALIGN(w, SCE_GXM_TILE_SIZEX);
         const uint32_t alignedHeight = ALIGN(h, SCE_GXM_TILE_SIZEY);
-        uint32_t sampleCount = alignedWidth*alignedHeight;
+        uint32_t sampleCount = alignedWidth * alignedHeight;
         uint32_t depthStrideInSamples = alignedWidth;
         const uint32_t alignedColorSurfaceStride = ALIGN(w, 8);
 
         int err = sceGxmColorSurfaceInit(
             &texture->gxm_colorsurface,
-            SCE_GXM_COLOR_FORMAT_A8B8G8R8,
+            tex_format_to_color_format(format),
             SCE_GXM_COLOR_SURFACE_LINEAR,
             SCE_GXM_COLOR_SURFACE_SCALE_NONE,
             SCE_GXM_OUTPUT_REGISTER_SIZE_32BIT,
             w,
             h,
             alignedColorSurfaceStride,
-            texture_data
-        );
+            texture_data);
 
         if (err < 0) {
             free_gxm_texture(data, texture);
@@ -1103,7 +1074,7 @@ create_gxm_texture(VITA_GXM_RenderData *data, unsigned int w, unsigned int h, Sc
         // allocate it
         depthBufferData = vita_mem_alloc(
             SCE_KERNEL_MEMBLOCK_TYPE_USER_RW_UNCACHE,
-            4*sampleCount,
+            4 * sampleCount,
             SCE_GXM_DEPTHSTENCIL_SURFACE_ALIGNMENT,
             SCE_GXM_MEMORY_ATTRIB_READ | SCE_GXM_MEMORY_ATTRIB_WRITE,
             &texture->depth_UID);
@@ -1148,14 +1119,12 @@ create_gxm_texture(VITA_GXM_RenderData *data, unsigned int w, unsigned int h, Sc
                 return NULL;
             }
         }
-
     }
 
     return texture;
 }
 
-void
-gxm_texture_set_filters(gxm_texture *texture, SceGxmTextureFilter min_filter, SceGxmTextureFilter mag_filter)
+void gxm_texture_set_filters(gxm_texture *texture, SceGxmTextureFilter min_filter, SceGxmTextureFilter mag_filter)
 {
     sceGxmTextureSetMinFilter(&texture->gxm_tex, min_filter);
     sceGxmTextureSetMagFilter(&texture->gxm_tex, mag_filter);
@@ -1166,7 +1135,7 @@ static unsigned int front_buffer_index_for_common_dialog = 0;
 struct
 {
     VITA_GXM_DisplayData displayData;
-    SceGxmSyncObject* sync;
+    SceGxmSyncObject *sync;
     SceGxmColorSurface surf;
     SceUID uid;
 } buffer_for_common_dialog[VITA_GXM_BUFFERS];
@@ -1175,11 +1144,11 @@ void gxm_minimal_init_for_common_dialog(void)
 {
     SceGxmInitializeParams initializeParams;
     SDL_zero(initializeParams);
-    initializeParams.flags                          = 0;
-    initializeParams.displayQueueMaxPendingCount    = VITA_GXM_PENDING_SWAPS;
-    initializeParams.displayQueueCallback           = display_callback;
-    initializeParams.displayQueueCallbackDataSize   = sizeof(VITA_GXM_DisplayData);
-    initializeParams.parameterBufferSize            = SCE_GXM_DEFAULT_PARAMETER_BUFFER_SIZE;
+    initializeParams.flags = 0;
+    initializeParams.displayQueueMaxPendingCount = VITA_GXM_PENDING_SWAPS;
+    initializeParams.displayQueueCallback = display_callback;
+    initializeParams.displayQueueCallbackDataSize = sizeof(VITA_GXM_DisplayData);
+    initializeParams.parameterBufferSize = SCE_GXM_DEFAULT_PARAMETER_BUFFER_SIZE;
     sceGxmInitialize(&initializeParams);
 }
 
@@ -1190,8 +1159,7 @@ void gxm_minimal_term_for_common_dialog(void)
 
 void gxm_init_for_common_dialog(void)
 {
-    for (int i = 0; i < VITA_GXM_BUFFERS; i += 1)
-    {
+    for (int i = 0; i < VITA_GXM_BUFFERS; i += 1) {
         buffer_for_common_dialog[i].displayData.wait_vblank = SDL_TRUE;
         buffer_for_common_dialog[i].displayData.address = vita_mem_alloc(
             SCE_KERNEL_MEMBLOCK_TYPE_USER_CDRAM_RW,
@@ -1208,8 +1176,7 @@ void gxm_init_for_common_dialog(void)
             VITA_GXM_SCREEN_WIDTH,
             VITA_GXM_SCREEN_HEIGHT,
             VITA_GXM_SCREEN_STRIDE,
-            buffer_for_common_dialog[i].displayData.address
-        );
+            buffer_for_common_dialog[i].displayData.address);
         sceGxmSyncObjectCreate(&buffer_for_common_dialog[i].sync);
     }
     sceGxmDisplayQueueFinish();
@@ -1219,10 +1186,10 @@ void gxm_swap_for_common_dialog(void)
 {
     SceCommonDialogUpdateParam updateParam;
     SDL_zero(updateParam);
-    updateParam.renderTarget.colorFormat    = VITA_GXM_PIXEL_FORMAT;
-    updateParam.renderTarget.surfaceType    = SCE_GXM_COLOR_SURFACE_LINEAR;
-    updateParam.renderTarget.width          = VITA_GXM_SCREEN_WIDTH;
-    updateParam.renderTarget.height         = VITA_GXM_SCREEN_HEIGHT;
+    updateParam.renderTarget.colorFormat = VITA_GXM_PIXEL_FORMAT;
+    updateParam.renderTarget.surfaceType = SCE_GXM_COLOR_SURFACE_LINEAR;
+    updateParam.renderTarget.width = VITA_GXM_SCREEN_WIDTH;
+    updateParam.renderTarget.height = VITA_GXM_SCREEN_HEIGHT;
     updateParam.renderTarget.strideInPixels = VITA_GXM_SCREEN_STRIDE;
 
     updateParam.renderTarget.colorSurfaceData = buffer_for_common_dialog[back_buffer_index_for_common_dialog].displayData.address;
@@ -1239,8 +1206,7 @@ void gxm_swap_for_common_dialog(void)
 void gxm_term_for_common_dialog(void)
 {
     sceGxmDisplayQueueFinish();
-    for (int i = 0; i < VITA_GXM_BUFFERS; i += 1)
-    {
+    for (int i = 0; i < VITA_GXM_BUFFERS; i += 1) {
         vita_mem_free(buffer_for_common_dialog[i].uid);
         sceGxmSyncObjectDestroy(buffer_for_common_dialog[i].sync);
     }
