@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2021 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -26,6 +26,7 @@
 #include "SDL_test_memory.h"
 
 #ifdef HAVE_LIBUNWIND_H
+#define UNW_LOCAL_ONLY
 #include <libunwind.h>
 #endif
 
@@ -61,7 +62,7 @@ static unsigned int get_allocation_bucket(void *mem)
     index = (crc_value & (SDL_arraysize(s_tracked_allocations) - 1));
     return index;
 }
- 
+
 static SDL_bool SDL_IsAllocationTracked(void *mem)
 {
     SDL_tracked_allocation *entry;
@@ -83,7 +84,7 @@ static void SDL_TrackAllocation(void *mem, size_t size)
         return;
     }
     entry = (SDL_tracked_allocation *)SDL_malloc_orig(sizeof(*entry));
-    if (!entry) {
+    if (entry == NULL) {
         return;
     }
     entry->mem = mem;
@@ -103,13 +104,13 @@ static void SDL_TrackAllocation(void *mem, size_t size)
         stack_index = 0;
         while (unw_step(&cursor) > 0) {
             unw_word_t offset, pc;
-            char sym[256];
+            char sym[236];
 
             unw_get_reg(&cursor, UNW_REG_IP, &pc);
             entry->stack[stack_index] = pc;
 
             if (unw_get_proc_name(&cursor, sym, sizeof(sym), &offset) == 0) {
-                snprintf(entry->stack_names[stack_index], sizeof(entry->stack_names[stack_index]), "%s+0x%llx", sym, (unsigned long long)offset);
+                SDL_snprintf(entry->stack_names[stack_index], sizeof(entry->stack_names[stack_index]), "%s+0x%llx", sym, (unsigned long long)offset);
             }
             ++stack_index;
 
@@ -144,7 +145,7 @@ static void SDL_UntrackAllocation(void *mem)
     }
 }
 
-static void * SDLCALL SDLTest_TrackedMalloc(size_t size)
+static void *SDLCALL SDLTest_TrackedMalloc(size_t size)
 {
     void *mem;
 
@@ -155,7 +156,7 @@ static void * SDLCALL SDLTest_TrackedMalloc(size_t size)
     return mem;
 }
 
-static void * SDLCALL SDLTest_TrackedCalloc(size_t nmemb, size_t size)
+static void *SDLCALL SDLTest_TrackedCalloc(size_t nmemb, size_t size)
 {
     void *mem;
 
@@ -166,11 +167,11 @@ static void * SDLCALL SDLTest_TrackedCalloc(size_t nmemb, size_t size)
     return mem;
 }
 
-static void * SDLCALL SDLTest_TrackedRealloc(void *ptr, size_t size)
+static void *SDLCALL SDLTest_TrackedRealloc(void *ptr, size_t size)
 {
     void *mem;
 
-    SDL_assert(!ptr || SDL_IsAllocationTracked(ptr));
+    SDL_assert(ptr == NULL || SDL_IsAllocationTracked(ptr));
     mem = SDL_realloc_orig(ptr, size);
     if (mem && mem != ptr) {
         if (ptr) {
@@ -183,7 +184,7 @@ static void * SDLCALL SDLTest_TrackedRealloc(void *ptr, size_t size)
 
 static void SDLCALL SDLTest_TrackedFree(void *ptr)
 {
-    if (!ptr) {
+    if (ptr == NULL) {
         return;
     }
 
@@ -232,13 +233,19 @@ void SDLTest_LogAllocations()
         return;
     }
 
-#define ADD_LINE() \
-    message_size += (SDL_strlen(line) + 1); \
+    message = SDL_realloc_orig(NULL, 1);
+    if (!message) {
+        return;
+    }
+    *message = 0;
+
+#define ADD_LINE()                                         \
+    message_size += (SDL_strlen(line) + 1);                \
     tmp = (char *)SDL_realloc_orig(message, message_size); \
-    if (!tmp) { \
-        return; \
-    } \
-    message = tmp; \
+    if (!tmp) {                                            \
+        return;                                            \
+    }                                                      \
+    message = tmp;                                         \
     SDL_strlcat(message, line, message_size)
 
     SDL_strlcpy(line, "Memory allocations:\n", sizeof(line));
@@ -250,21 +257,21 @@ void SDLTest_LogAllocations()
     total_allocated = 0;
     for (index = 0; index < SDL_arraysize(s_tracked_allocations); ++index) {
         for (entry = s_tracked_allocations[index]; entry; entry = entry->next) {
-            SDL_snprintf(line, sizeof(line), "Allocation %d: %d bytes\n", count, (int)entry->size);
+            (void)SDL_snprintf(line, sizeof(line), "Allocation %d: %d bytes\n", count, (int)entry->size);
             ADD_LINE();
             /* Start at stack index 1 to skip our tracking functions */
             for (stack_index = 1; stack_index < SDL_arraysize(entry->stack); ++stack_index) {
                 if (!entry->stack[stack_index]) {
                     break;
                 }
-                SDL_snprintf(line, sizeof(line), "\t0x%"SDL_PRIx64": %s\n", entry->stack[stack_index], entry->stack_names[stack_index]);
+                (void)SDL_snprintf(line, sizeof(line), "\t0x%" SDL_PRIx64 ": %s\n", entry->stack[stack_index], entry->stack_names[stack_index]);
                 ADD_LINE();
             }
             total_allocated += entry->size;
             ++count;
         }
     }
-    SDL_snprintf(line, sizeof(line), "Total: %.2f Kb in %d allocations\n", (float)total_allocated / 1024, count);
+    (void)SDL_snprintf(line, sizeof(line), "Total: %.2f Kb in %d allocations\n", total_allocated / 1024.0, count);
     ADD_LINE();
 #undef ADD_LINE
 
