@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -42,14 +42,16 @@ struct qt_surface_extension;
 struct qt_windowmanager;
 #endif /* SDL_VIDEO_DRIVER_WAYLAND_QT_TOUCH */
 
-typedef struct {
+typedef struct
+{
     struct wl_cursor_theme *theme;
     int size;
 } SDL_WaylandCursorTheme;
 
 typedef struct SDL_WaylandOutputData SDL_WaylandOutputData;
 
-typedef struct {
+typedef struct
+{
     SDL_bool initializing;
     struct wl_display *display;
     int display_disconnected;
@@ -59,7 +61,8 @@ typedef struct {
     SDL_WaylandCursorTheme *cursor_themes;
     int num_cursor_themes;
     struct wl_pointer *pointer;
-    struct {
+    struct
+    {
         struct xdg_wm_base *xdg;
 #ifdef HAVE_LIBDECOR_H
         struct libdecor *libdecor;
@@ -68,6 +71,7 @@ typedef struct {
     struct zwp_relative_pointer_manager_v1 *relative_pointer_manager;
     struct zwp_pointer_constraints_v1 *pointer_constraints;
     struct wl_data_device_manager *data_device_manager;
+    struct zwp_primary_selection_device_manager_v1 *primary_selection_device_manager;
     struct zxdg_decoration_manager_v1 *decoration_manager;
     struct zwp_keyboard_shortcuts_inhibit_manager_v1 *key_inhibitor_manager;
     struct zwp_idle_inhibit_manager_v1 *idle_inhibit_manager;
@@ -75,6 +79,7 @@ typedef struct {
     struct zwp_text_input_manager_v3 *text_input_manager;
     struct zxdg_output_manager_v1 *xdg_output_manager;
     struct wp_viewporter *viewporter;
+    struct wp_fractional_scale_manager_v1 *fractional_scale_manager;
 
     EGLDisplay edpy;
     EGLContext context;
@@ -94,9 +99,11 @@ typedef struct {
     char *classname;
 
     int relative_mouse_mode;
+    SDL_bool egl_transparency_enabled;
 } SDL_VideoData;
 
-struct SDL_WaylandOutputData {
+struct SDL_WaylandOutputData
+{
     SDL_VideoData *videodata;
     struct wl_output *output;
     struct zxdg_output_v1 *xdg_output;
@@ -124,6 +131,8 @@ extern SDL_bool SDL_WAYLAND_own_output(struct wl_output *output);
 
 extern SDL_bool Wayland_LoadLibdecor(SDL_VideoData *data, SDL_bool ignore_xdg);
 
+extern SDL_bool Wayland_VideoReconnect(_THIS);
+
 #endif /* SDL_waylandvideo_h_ */
 
 /* vi: set ts=4 sw=4 expandtab: */
