@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1997-2021 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -21,9 +21,10 @@
 
 #include "SDL_test.h"
 #include "SDL_test_common.h"
+#include "testutils.h"
 
-#define NUM_SPRITES    100
-#define MAX_SPEED     1
+#define NUM_SPRITES 100
+#define MAX_SPEED   1
 
 static SDLTest_CommonState *state;
 static int num_sprites;
@@ -55,68 +56,36 @@ quit(int rc)
     SDL_free(positions);
     SDL_free(velocities);
     SDLTest_CommonQuit(state);
-    exit(rc);
+    /* If rc is 0, just let main return normally rather than calling exit.
+     * This allows testing of platforms where SDL_main is required and does meaningful cleanup.
+     */
+    if (rc != 0) {
+        exit(rc);
+    }
 }
 
-int
-LoadSprite(const char *file)
+int LoadSprite(const char *file)
 {
     int i;
-    SDL_Surface *temp;
 
-    /* Load the sprite image */
-    temp = SDL_LoadBMP(file);
-    if (temp == NULL) {
-        SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Couldn't load %s: %s", file, SDL_GetError());
-        return (-1);
-    }
-    sprite_w = temp->w;
-    sprite_h = temp->h;
-
-    /* Set transparent pixel as the pixel at (0,0) */
-    if (temp->format->palette) {
-        SDL_SetColorKey(temp, 1, *(Uint8 *) temp->pixels);
-    } else {
-        switch (temp->format->BitsPerPixel) {
-        case 15:
-            SDL_SetColorKey(temp, 1, (*(Uint16 *) temp->pixels) & 0x00007FFF);
-            break;
-        case 16:
-            SDL_SetColorKey(temp, 1, *(Uint16 *) temp->pixels);
-            break;
-        case 24:
-            SDL_SetColorKey(temp, 1, (*(Uint32 *) temp->pixels) & 0x00FFFFFF);
-            break;
-        case 32:
-            SDL_SetColorKey(temp, 1, *(Uint32 *) temp->pixels);
-            break;
-        }
-    }
-
-    /* Create textures from the image */
     for (i = 0; i < state->num_windows; ++i) {
-        SDL_Renderer *renderer = state->renderers[i];
-        sprites[i] = SDL_CreateTextureFromSurface(renderer, temp);
+        /* This does the SDL_LoadBMP step repeatedly, but that's OK for test code. */
+        sprites[i] = LoadTexture(state->renderers[i], file, SDL_TRUE, &sprite_w, &sprite_h);
         if (!sprites[i]) {
-            SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Couldn't create texture: %s\n", SDL_GetError());
-            SDL_FreeSurface(temp);
-            return (-1);
+            return -1;
         }
         if (SDL_SetTextureBlendMode(sprites[i], blendMode) < 0) {
             SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Couldn't set blend mode: %s\n", SDL_GetError());
-            SDL_FreeSurface(temp);
             SDL_DestroyTexture(sprites[i]);
-            return (-1);
+            return -1;
         }
     }
-    SDL_FreeSurface(temp);
 
     /* We're ready to roll. :) */
-    return (0);
+    return 0;
 }
 
-void
-MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
+void MoveSprites(SDL_Renderer *renderer, SDL_Texture *sprite)
 {
     int i;
     SDL_Rect viewport, temp;
@@ -136,8 +105,8 @@ MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
             current_color = 255;
             cycle_direction = -cycle_direction;
         }
-        SDL_SetTextureColorMod(sprite, 255, (Uint8) current_color,
-                               (Uint8) current_color);
+        SDL_SetTextureColorMod(sprite, 255, (Uint8)current_color,
+                               (Uint8)current_color);
     }
     if (cycle_alpha) {
         current_alpha += cycle_direction;
@@ -149,7 +118,7 @@ MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
             current_alpha = 255;
             cycle_direction = -cycle_direction;
         }
-        SDL_SetTextureAlphaMod(sprite, (Uint8) current_alpha);
+        SDL_SetTextureAlphaMod(sprite, (Uint8)current_alpha);
     }
 
     /* Draw a gray background */
@@ -159,16 +128,16 @@ MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
     /* Test points */
     SDL_SetRenderDrawColor(renderer, 0xFF, 0x00, 0x00, 0xFF);
     SDL_RenderDrawPoint(renderer, 0, 0);
-    SDL_RenderDrawPoint(renderer, viewport.w-1, 0);
-    SDL_RenderDrawPoint(renderer, 0, viewport.h-1);
-    SDL_RenderDrawPoint(renderer, viewport.w-1, viewport.h-1);
+    SDL_RenderDrawPoint(renderer, viewport.w - 1, 0);
+    SDL_RenderDrawPoint(renderer, 0, viewport.h - 1);
+    SDL_RenderDrawPoint(renderer, viewport.w - 1, viewport.h - 1);
 
     /* Test horizontal and vertical lines */
     SDL_SetRenderDrawColor(renderer, 0x00, 0xFF, 0x00, 0xFF);
-    SDL_RenderDrawLine(renderer, 1, 0, viewport.w-2, 0);
-    SDL_RenderDrawLine(renderer, 1, viewport.h-1, viewport.w-2, viewport.h-1);
-    SDL_RenderDrawLine(renderer, 0, 1, 0, viewport.h-2);
-    SDL_RenderDrawLine(renderer, viewport.w-1, 1, viewport.w-1, viewport.h-2);
+    SDL_RenderDrawLine(renderer, 1, 0, viewport.w - 2, 0);
+    SDL_RenderDrawLine(renderer, 1, viewport.h - 1, viewport.w - 2, viewport.h - 1);
+    SDL_RenderDrawLine(renderer, 0, 1, 0, viewport.h - 2);
+    SDL_RenderDrawLine(renderer, viewport.w - 1, 1, viewport.w - 1, viewport.h - 2);
 
     /* Test fill and copy */
     SDL_SetRenderDrawColor(renderer, 0xFF, 0xFF, 0xFF, 0xFF);
@@ -209,20 +178,20 @@ MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
         SDL_RenderGeometry(renderer, NULL, verts, 3, NULL, 0);
     }
     SDL_RenderCopy(renderer, sprite, NULL, &temp);
-    temp.x = viewport.w-sprite_w-1;
+    temp.x = viewport.w - sprite_w - 1;
     temp.y = 1;
     temp.w = sprite_w;
     temp.h = sprite_h;
     SDL_RenderFillRect(renderer, &temp);
     SDL_RenderCopy(renderer, sprite, NULL, &temp);
     temp.x = 1;
-    temp.y = viewport.h-sprite_h-1;
+    temp.y = viewport.h - sprite_h - 1;
     temp.w = sprite_w;
     temp.h = sprite_h;
     SDL_RenderFillRect(renderer, &temp);
     SDL_RenderCopy(renderer, sprite, NULL, &temp);
-    temp.x = viewport.w-sprite_w-1;
-    temp.y = viewport.h-sprite_h-1;
+    temp.x = viewport.w - sprite_w - 1;
+    temp.y = viewport.h - sprite_h - 1;
     temp.w = sprite_w;
     temp.h = sprite_h;
     SDL_RenderFillRect(renderer, &temp);
@@ -231,9 +200,9 @@ MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
     /* Test diagonal lines */
     SDL_SetRenderDrawColor(renderer, 0x00, 0xFF, 0x00, 0xFF);
     SDL_RenderDrawLine(renderer, sprite_w, sprite_h,
-                       viewport.w-sprite_w-2, viewport.h-sprite_h-2);
-    SDL_RenderDrawLine(renderer, viewport.w-sprite_w-2, sprite_h,
-                       sprite_w, viewport.h-sprite_h-2);
+                       viewport.w - sprite_w - 2, viewport.h - sprite_h - 2);
+    SDL_RenderDrawLine(renderer, viewport.w - sprite_w - 2, sprite_h,
+                       sprite_w, viewport.h - sprite_h - 2);
 
     /* Conditionally move the sprites, bounce at the wall */
     if (iterations == -1 || iterations > 0) {
@@ -250,7 +219,6 @@ MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
                 velocity->y = -velocity->y;
                 position->y += velocity->y;
             }
-
         }
 
         /* Countdown sprite-move iterations and disable color changes at iteration end - used for visual tests. */
@@ -280,7 +248,7 @@ MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
          *
          *  Draw sprite2 as triangles that can be recombined as rect by software renderer
          */
-        SDL_Vertex *verts = (SDL_Vertex *) SDL_malloc(num_sprites * sizeof (SDL_Vertex) * 6);
+        SDL_Vertex *verts = (SDL_Vertex *)SDL_malloc(num_sprites * sizeof(SDL_Vertex) * 6);
         SDL_Vertex *verts2 = verts;
         if (verts) {
             SDL_Color color;
@@ -348,9 +316,9 @@ MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
          * Draw sprite2 as triangles that can *not* be recombined as rect by software renderer
          * Use an 'indices' array
          */
-        SDL_Vertex *verts = (SDL_Vertex *) SDL_malloc(num_sprites * sizeof (SDL_Vertex) * 5);
+        SDL_Vertex *verts = (SDL_Vertex *)SDL_malloc(num_sprites * sizeof(SDL_Vertex) * 5);
         SDL_Vertex *verts2 = verts;
-        int *indices = (int *) SDL_malloc(num_sprites * sizeof (int) * 4 * 3);
+        int *indices = (int *)SDL_malloc(num_sprites * sizeof(int) * 4 * 3);
         int *indices2 = indices;
         if (verts && indices) {
             int pos = 0;
@@ -424,8 +392,7 @@ MoveSprites(SDL_Renderer * renderer, SDL_Texture * sprite)
     SDL_RenderPresent(renderer);
 }
 
-void
-loop()
+void loop()
 {
     Uint32 now;
     int i;
@@ -436,8 +403,9 @@ loop()
         SDLTest_CommonEvent(state, &event, &done);
     }
     for (i = 0; i < state->num_windows; ++i) {
-        if (state->windows[i] == NULL)
+        if (state->windows[i] == NULL) {
             continue;
+        }
         MoveSprites(state->renderers[i], sprites[i]);
     }
 #ifdef __EMSCRIPTEN__
@@ -451,16 +419,14 @@ loop()
     if (SDL_TICKS_PASSED(now, next_fps_check)) {
         /* Print out some timing information */
         const Uint32 then = next_fps_check - fps_check_delay;
-        const double fps = ((double) frames * 1000) / (now - then);
+        const double fps = ((double)frames * 1000) / (now - then);
         SDL_Log("%2.2f frames per second\n", fps);
         next_fps_check = now + fps_check_delay;
         frames = 0;
     }
-
 }
 
-int
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
     int i;
     Uint64 seed;
@@ -471,7 +437,7 @@ main(int argc, char *argv[])
 
     /* Initialize test framework */
     state = SDLTest_CommonCreateState(argv, SDL_INIT_VIDEO);
-    if (!state) {
+    if (state == NULL) {
         return 1;
     }
 
@@ -503,7 +469,9 @@ main(int argc, char *argv[])
             } else if (SDL_strcasecmp(argv[i], "--iterations") == 0) {
                 if (argv[i + 1]) {
                     iterations = SDL_atoi(argv[i + 1]);
-                    if (iterations < -1) iterations = -1;
+                    if (iterations < -1) {
+                        iterations = -1;
+                    }
                     consumed = 2;
                 }
             } else if (SDL_strcasecmp(argv[i], "--cyclecolor") == 0) {
@@ -543,7 +511,8 @@ main(int argc, char *argv[])
                 "[--use-rendergeometry mode1|mode2]",
                 "[num_sprites]",
                 "[icon.bmp]",
-                NULL };
+                NULL
+            };
             SDLTest_CommonLogUsage(state, argv[0], options);
             quit(1);
         }
@@ -555,8 +524,8 @@ main(int argc, char *argv[])
 
     /* Create the windows, initialize the renderers, and load the textures */
     sprites =
-        (SDL_Texture **) SDL_malloc(state->num_windows * sizeof(*sprites));
-    if (!sprites) {
+        (SDL_Texture **)SDL_malloc(state->num_windows * sizeof(*sprites));
+    if (sprites == NULL) {
         SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Out of memory!\n");
         quit(2);
     }
@@ -570,9 +539,9 @@ main(int argc, char *argv[])
     }
 
     /* Allocate memory for the sprite info */
-    positions = (SDL_Rect *) SDL_malloc(num_sprites * sizeof(SDL_Rect));
-    velocities = (SDL_Rect *) SDL_malloc(num_sprites * sizeof(SDL_Rect));
-    if (!positions || !velocities) {
+    positions = (SDL_Rect *)SDL_malloc(num_sprites * sizeof(SDL_Rect));
+    velocities = (SDL_Rect *)SDL_malloc(num_sprites * sizeof(SDL_Rect));
+    if (positions == NULL || velocities == NULL) {
         SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Out of memory!\n");
         quit(2);
     }
